@@ -63,9 +63,9 @@
 #!   \code{\link{read.table.ffdf}}, \code{\link{levels.ff}}
 #! }
 #! \examples{
-#!   cat("Let's create a factor with little levels\n")
+#!   message("Let's create a factor with little levels")
 #!   x <- ff(letters[4:6], levels=letters[4:6])
-#!   cat("Let's interpret the same ff file without levels in order to see the codes\n")
+#!   message("Let's interpret the same ff file without levels in order to see the codes")
 #!   y <- x
 #!   levels(y) <- NULL
 #!
@@ -80,9 +80,9 @@
 #!   levels(x)
 #!   data.frame(factor=x[], codes=y[])
 #!
-#!   cat("NEVER forget to reassign the result of recodeLevels or sortLevels, look at the following mess\n")
+#!   message("NEVER forget to reassign the result of recodeLevels or sortLevels, look at the following mess")
 #!   recodeLevels(x, rev(levels(x)))
-#!   cat("NOW the codings have changed, but not the levels, the result is wrong data\n")
+#!   message("NOW the codings have changed, but not the levels, the result is wrong data")
 #!   levels(x)
 #!   data.frame(factor=x[], codes=y[])
 #!
@@ -91,7 +91,7 @@
 #! \dontrun{
 #!  n <- 5e7
 #!
-#!  cat("reading a factor from a file ist as fast ...\n")
+#!  message("reading a factor from a file ist as fast ...")
 #!  system.time(
 #!  fx <- ff(factor(letters[1:25]), length=n)
 #!  )
@@ -100,7 +100,7 @@
 #!  rm(x); gc()
 #!
 #!
-#!  cat("... as creating it in-RAM (R-2.11.1) which is theoretically impossible ...\n")
+#!  message("... as creating it in-RAM (R-2.11.1) which is theoretically impossible ...")
 #!  system.time({
 #!  x <- integer(n)
 #!  x[] <- 1:25
@@ -111,7 +111,7 @@
 #!  rm(x); gc()
 #!
 #!
-#!  cat("... but is possible if we avoid some  unnecessary copying that is triggered by assignment functions\n")
+#!  message("... but is possible if we avoid some  unnecessary copying that is triggered by assignment functions")
 #!  system.time({
 #!  x <- integer(n)
 #!  x[] <- 1:25
@@ -168,7 +168,7 @@ recodeLevels.ff <- function(x, lev){
 sortLevels.factor <- function(x){
   l <- levels(x)
   o <- order(l)
-  if (identical(o, seq.int(along=o)))
+  if (identical(o, seq_along(o)))
     x
   else
     recodeLevels.factor(x, l[o])
@@ -177,14 +177,14 @@ sortLevels.factor <- function(x){
 sortLevels.ff <- function(x){
   l <- levels(x)
   o <- order(l)
-  if (identical(o, seq.int(along=o)))
+  if (identical(o, seq_along(o)))
     x
   else
     recodeLevels.ff(x, l[o])
 }
 
 sortLevels.ffdf <- function(x){
-  for (i in seq.int(length=ncol(x))){
+  for (i in seq_len(ncol(x))){
     y <- x[[i]]
     if (is.factor(y))
       x[[i]] <- sortLevels.ff(y)
